==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property acm TLS validation context trust for an AWS Certificate Manager (ACM) certificate.
 * @property file TLS validation context trust for a local file certificate.
 * @property sds TLS validation context trust for a [Secret Discovery Service](https://www.envoyproxy.io/docs/envoy/latest/configuration/security/secret#secret-discovery-service-sds) certificate.
 */
public data class VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust(
    public val acm: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustAcm? = null,
    public val `file`: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustFile? = null,
    public val sds: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustSds? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust):
            VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust =
            VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust(
                acm = javaType.acm().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                `file` = javaType.`file`().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustFile.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustSds.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Suppress

/**
 *
 * @property acm TLS validation context trust for an AWS Certificate Manager (ACM) certificate.
 * @property file TLS validation context trust for a local file certificate.
 * @property sds TLS validation context trust for a [Secret Discovery Service](https://www.envoyproxy.io/docs/envoy/latest/configuration/security/secret#secret-discovery-service-sds) certificate.
 */
public data class VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust(
    public val acm: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustAcm? = null,
    public val `file`: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustFile? = null,
    public val sds: VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustSds? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust): VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust =
            VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrust(
                acm = javaType.acm().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustAcm.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                `file` = javaType.`file`().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustFile.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                sds = javaType.sds().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.aws.appmesh.kotlin.outputs.VirtualNodeSpecBackendDefaultsClientPolicyTlsValidationTrustSds.Companion.toKotlin(args0)
                    })
                }).orElse(null),
            )
    }
}
